#!/bin/bash
# GENERATED at packaging time by scripts/packaging/pack-object-files.sh
# from the very build this archive was created from - do not edit.
#
# Relinks the shipped object files into the static executables
# (arangod, arangobench, arangodump, arangoexport, arangoimport, arangorestore, arangosh, arangovpack, arangobackup),
# so they can be rebuilt against your own (newer) glibc.
# Use Ubuntu 24.04 (with glibc 2.39 or later) and install:
#   apt install build-essential clang-19 lld-19 liburing-dev \
#       libblas-dev liblapack-dev gfortran
# Execute in the directory in which you extracted the archive!
set -e
cd build

echo arangod
clang++-19 -Wall -Wextra -Wno-unused-parameter -Wno-deprecated-declarations -Wno-error=unused-command-line-argument -mlittle-endian -march=armv8-a+crc+crypto -fno-stack-protector -Wsuggest-override -Wnon-virtual-dtor -Wno-missing-designated-field-initializers -g1 -gno-column-info -gz -O3 -fno-omit-frame-pointer -fstandalone-debug -Wl,--build-id=sha1 -fno-stack-protector -fuse-ld=lld -fopenmp=libgomp -llapack -lgfortran -static -fopenmp=libgomp -llapack -lgfortran ../lib/BuildId/BuildId.ld -Wl,--build-id=sha1 arangod/CMakeFiles/arangod.dir/RestServer/arangod.cpp.o -o bin/arangod -Lbin -L3rdParty/zlib/zlib-1.2.13 -L3rdParty/v8-build/v8/arm64.release/gypfiles -L3rdParty/v8-build/v8/arm64.release/obj.target/third_party/icu -L3rdParty/rocksdb bin/libarango_iresearch.a 3rdParty/jemalloc/lib/libjemalloc.a bin/libarango_feature_phases.a bin/libarango_rest_server.a bin/libarango_sharding.a bin/libarango_vector_index.a bin/libarango_system_monitor_activities.a bin/libarango_system_monitor_async_registry.a bin/libarango_cluster_engine_rest.a bin/libarango_rocksdb_rest.a bin/libarango_common_rest_handler.a bin/libarango_scheduler.a bin/libarango_enterprise_sharding.a bin/libarango_enterprise_ssl.a bin/libarango_iresearch.a bin/libarango_actions.a bin/libarango_auth.a bin/libarango_cluster.a bin/libarango_general_server.a bin/libarango_rest_handler.a bin/libarango_statistics.a bin/libarango_transaction.a bin/libarango_agency.a bin/libarango_cluster_engine.a bin/libarango_cluster_methods.a bin/libarango_graph.a bin/libarango_indexes.a bin/libarango_metrics.a bin/libarango_network.a bin/libarango_replication.a bin/libarango_storage_engine.a bin/libarango_utils.a bin/libarango_vocbase.a bin/libarango_enterprise_rest_handler.a bin/libarango_enterprise_storage_engine.a bin/libarango_v8server.a bin/libarango.a bin/libarango_v8_no_deadline.a bin/libarango_aql.a bin/libarango_cache.a bin/libarango_replication2.a bin/libarango_rocksdb.a bin/libarango_vocbase_api.a bin/libarango_lightweight.a bin/libarango_replication2_pure.a bin/libarango_storage_engine_common.a bin/libarango_rclone.a bin/libarango_iresearch.a bin/libarango_actions.a bin/libarango_auth.a bin/libarango_cluster.a bin/libarango_general_server.a bin/libarango_rest_handler.a bin/libarango_statistics.a bin/libarango_transaction.a bin/libarango_agency.a bin/libarango_cluster_engine.a bin/libarango_cluster_methods.a bin/libarango_graph.a bin/libarango_indexes.a bin/libarango_metrics.a bin/libarango_network.a bin/libarango_replication.a bin/libarango_storage_engine.a bin/libarango_utils.a bin/libarango_vocbase.a bin/libarango_enterprise_rest_handler.a bin/libarango_enterprise_storage_engine.a bin/libarango_v8server.a bin/libarango.a bin/libarango_v8_no_deadline.a bin/libarango_aql.a bin/libarango_cache.a bin/libarango_replication2.a bin/libarango_rocksdb.a bin/libarango_vocbase_api.a bin/libarango_lightweight.a bin/libarango_replication2_pure.a bin/libarango_storage_engine_common.a bin/libarango_rclone.a bin/libboost_thread.a bin/libiresearch-s.a bin/libanalyzer-delimiter-s.a bin/libanalyzer-multi-delimiter-s.a bin/libanalyzer-ngram-s.a bin/libanalyzer-text-s.a bin/libanalyzer-norm-s.a bin/libanalyzer-minhash-s.a bin/libanalyzer-collation-s.a bin/libanalyzer-stem-s.a bin/libanalyzer-stopwords-s.a bin/libanalyzer-pipeline-s.a bin/libanalyzer-segmentation-s.a bin/libanalyzer-classification-s.a bin/libanalyzer-nearest-neighbors-s.a bin/libformat-1_0-s.a bin/libscorer-bm25-s.a bin/libscorer-tfidf-s.a bin/libiresearch-s.a bin/libanalyzer-delimiter-s.a bin/libanalyzer-multi-delimiter-s.a bin/libanalyzer-ngram-s.a bin/libanalyzer-text-s.a bin/libanalyzer-norm-s.a bin/libanalyzer-minhash-s.a bin/libanalyzer-collation-s.a bin/libanalyzer-stem-s.a bin/libanalyzer-stopwords-s.a bin/libanalyzer-pipeline-s.a bin/libanalyzer-segmentation-s.a bin/libanalyzer-classification-s.a bin/libanalyzer-nearest-neighbors-s.a bin/libformat-1_0-s.a bin/libscorer-bm25-s.a bin/libscorer-tfidf-s.a bin/libsimdcomp-static.a -std=c99 -fPIC -Wextra -pedantic -Wshadow -O3 -g -D__ARM_NEON__ bin/libstemmer-static.a bin/libtext.a bin/libfasttext.a bin/libarango_enterprise_license.a bin/libarango_v8.a bin/libarango_basic_features.a bin/libarango_basic_http_client.a bin/libzlibstatic.a -licui18n -licuucx -licustubdata -latomic -lresolv -lrt -ltorque_base -lv8_base_without_compiler -lv8_compiler -lv8_init -lv8_initializers -lv8_turboshaft -lv8_libbase -lv8_libplatform -lv8_snapshot 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a bin/libarango_geo.a bin/libarango_enterprise_audit.a bin/libarango-validation.a bin/libarango_health.a bin/libarango_restart_action.a bin/libarango_zkd.a bin/librocksdb.a 3rdParty/jemalloc/lib/libjemalloc.a /usr/lib/aarch64-linux-gnu/liburing.a bin/libfaiss.a /usr/lib/gcc/aarch64-linux-gnu/13/libgomp.a -lpthread /usr/lib/aarch64-linux-gnu/libblas.a /usr/lib/aarch64-linux-gnu/lapack/liblapack.a bin/libarango_static_strings.a bin/libarango_basic_logger.a bin/libarango_async.a bin/libarango_async_registry.a bin/libarango_metrics_base.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libarango_futures.a bin/libarango_assertions.a bin/libarango_crashhandler.a bin/libarango_build_id.a 3rdParty/libunwind/v1.7.2/src/.libs/libunwind.a bin/libs2.a bin/libabsl_str_format_internal.a bin/libfuerte.a bin/libboost_system.a bin/libllhttp.a bin/libnghttp2.a bin/liblz4.a bin/liblinenoise-ng.a bin/libsnappy.a bin/libarango_basic_errors.a bin/libabsl_cord.a bin/libabsl_cordz_info.a bin/libabsl_cord_internal.a bin/libabsl_cordz_functions.a bin/libabsl_cordz_handle.a bin/libabsl_crc_cord_state.a bin/libabsl_crc32c.a bin/libabsl_crc_internal.a bin/libabsl_crc_cpu_detect.a bin/libabsl_raw_hash_set.a bin/libabsl_hash.a bin/libabsl_city.a bin/libabsl_bad_variant_access.a bin/libabsl_low_level_hash.a bin/libabsl_bad_optional_access.a bin/libabsl_hashtablez_sampler.a bin/libabsl_exponential_biased.a bin/libabsl_synchronization.a bin/libabsl_graphcycles_internal.a bin/libabsl_kernel_timeout_internal.a bin/libabsl_stacktrace.a bin/libabsl_symbolize.a bin/libabsl_malloc_internal.a bin/libabsl_debugging_internal.a bin/libabsl_demangle_internal.a bin/libabsl_time.a bin/libabsl_civil_time.a bin/libabsl_time_zone.a bin/libabsl_strings.a bin/libabsl_int128.a bin/libabsl_throw_delegate.a bin/libabsl_strings_internal.a bin/libabsl_base.a bin/libabsl_spinlock_wait.a -lrt bin/libabsl_raw_logging_internal.a bin/libabsl_log_severity.a bin/libvelocypack.a libssl.a libcrypto.a -ldl

echo arangobench
clang++-19 -Wall -Wextra -Wno-unused-parameter -Wno-deprecated-declarations -Wno-error=unused-command-line-argument -mlittle-endian -march=armv8-a+crc+crypto -fno-stack-protector -Wsuggest-override -Wnon-virtual-dtor -Wno-missing-designated-field-initializers -g1 -gno-column-info -gz -O3 -fno-omit-frame-pointer -fstandalone-debug -Wl,--build-id=sha1 -fno-stack-protector -fuse-ld=lld -fopenmp=libgomp -llapack -lgfortran -static ../lib/BuildId/BuildId.ld -Wl,--build-id=sha1 client-tools/Benchmark/CMakeFiles/arangobench.dir/arangobench.cpp.o client-tools/Benchmark/CMakeFiles/arangobench.dir/ArangoBenchServer.cpp.o client-tools/Benchmark/CMakeFiles/arangobench.dir/BenchFeature.cpp.o client-tools/Benchmark/CMakeFiles/arangobench.dir/BenchOptionsProvider.cpp.o client-tools/Benchmark/CMakeFiles/arangobench.dir/BenchmarkOperation.cpp.o client-tools/Benchmark/CMakeFiles/arangobench.dir/testcases/helpers.cpp.o -o bin/arangobench -Lbin -L3rdParty/zlib/zlib-1.2.13 -L3rdParty/v8-build/v8/arm64.release/gypfiles -L3rdParty/v8-build/v8/arm64.release/obj.target/third_party/icu -L3rdParty/rocksdb bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a libssl.a libcrypto.a -ldl -latomic -lresolv -lrt 3rdParty/jemalloc/lib/libjemalloc.a -ldl bin/libboost_system.a bin/libarango_shell.a bin/libclienttools_utils.a 3rdParty/jemalloc/lib/libjemalloc.a bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a -latomic -lresolv -lrt bin/libarango_static_strings.a bin/libarango_basic_features.a bin/libarango_basic_logger.a bin/libarango_basic_http_client.a bin/librocksdb.a 3rdParty/jemalloc/lib/libjemalloc.a /usr/lib/aarch64-linux-gnu/liburing.a bin/libarango_scheduler.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libfuerte.a bin/libnghttp2.a bin/libllhttp.a bin/libs2.a libssl.a libcrypto.a -ldl bin/libabsl_str_format_internal.a bin/liblinenoise-ng.a bin/libsnappy.a bin/liblz4.a bin/libarango_futures.a bin/libarango_assertions.a bin/libarango_crashhandler.a bin/libboost_system.a bin/libarango_basic_errors.a bin/libabsl_cord.a bin/libabsl_cordz_info.a bin/libabsl_cord_internal.a bin/libabsl_cordz_functions.a bin/libabsl_cordz_handle.a bin/libabsl_crc_cord_state.a bin/libabsl_crc32c.a bin/libabsl_crc_internal.a bin/libabsl_crc_cpu_detect.a bin/libabsl_raw_hash_set.a bin/libabsl_hash.a bin/libabsl_city.a bin/libabsl_bad_variant_access.a bin/libabsl_low_level_hash.a bin/libabsl_hashtablez_sampler.a bin/libabsl_exponential_biased.a bin/libabsl_synchronization.a bin/libabsl_stacktrace.a bin/libabsl_graphcycles_internal.a bin/libabsl_kernel_timeout_internal.a bin/libabsl_symbolize.a bin/libabsl_malloc_internal.a bin/libabsl_debugging_internal.a bin/libabsl_demangle_internal.a bin/libabsl_time.a bin/libabsl_strings.a bin/libabsl_strings_internal.a bin/libabsl_throw_delegate.a bin/libabsl_base.a bin/libabsl_spinlock_wait.a -lrt bin/libabsl_int128.a bin/libabsl_civil_time.a bin/libabsl_time_zone.a bin/libabsl_bad_optional_access.a bin/libabsl_raw_logging_internal.a bin/libabsl_log_severity.a bin/libvelocypack.a bin/libarango_build_id.a 3rdParty/libunwind/v1.7.2/src/.libs/libunwind.a -ltorque_base -lv8_base_without_compiler -lv8_compiler -lv8_init -lv8_initializers -lv8_turboshaft -lv8_libbase -lv8_libplatform -lv8_snapshot

echo arangodump
clang++-19 -Wall -Wextra -Wno-unused-parameter -Wno-deprecated-declarations -Wno-error=unused-command-line-argument -mlittle-endian -march=armv8-a+crc+crypto -fno-stack-protector -Wsuggest-override -Wnon-virtual-dtor -Wno-missing-designated-field-initializers -g1 -gno-column-info -gz -O3 -fno-omit-frame-pointer -fstandalone-debug -Wl,--build-id=sha1 -fno-stack-protector -fuse-ld=lld -fopenmp=libgomp -llapack -lgfortran -static ../lib/BuildId/BuildId.ld -Wl,--build-id=sha1 client-tools/Dump/CMakeFiles/arangodump.dir/ArangoDumpServer.cpp.o client-tools/Dump/CMakeFiles/arangodump.dir/DumpFeature.cpp.o client-tools/Dump/CMakeFiles/arangodump.dir/DumpFeatureOptions.cpp.o client-tools/Dump/CMakeFiles/arangodump.dir/DumpOptionsProvider.cpp.o client-tools/Dump/CMakeFiles/arangodump.dir/arangodump.cpp.o client-tools/Dump/CMakeFiles/arangodump.dir/__/__/enterprise/Enterprise/Maskings/AttributeMaskingEE.cpp.o client-tools/Dump/CMakeFiles/arangodump.dir/__/__/enterprise/Enterprise/Maskings/CreditCardMask.cpp.o client-tools/Dump/CMakeFiles/arangodump.dir/__/__/enterprise/Enterprise/Maskings/DateMask.cpp.o client-tools/Dump/CMakeFiles/arangodump.dir/__/__/enterprise/Enterprise/Maskings/DecimalMask.cpp.o client-tools/Dump/CMakeFiles/arangodump.dir/__/__/enterprise/Enterprise/Maskings/EmailMask.cpp.o client-tools/Dump/CMakeFiles/arangodump.dir/__/__/enterprise/Enterprise/Maskings/IntegerMask.cpp.o client-tools/Dump/CMakeFiles/arangodump.dir/__/__/enterprise/Enterprise/Maskings/XifyFront.cpp.o client-tools/Dump/CMakeFiles/arangodump.dir/__/__/enterprise/Enterprise/Maskings/ZipMask.cpp.o -o bin/arangodump -Lbin -L3rdParty/zlib/zlib-1.2.13 -L3rdParty/v8-build/v8/arm64.release/gypfiles -L3rdParty/v8-build/v8/arm64.release/obj.target/third_party/icu -L3rdParty/rocksdb bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a libssl.a libcrypto.a -ldl -latomic -lresolv -lrt 3rdParty/jemalloc/lib/libjemalloc.a -ldl bin/libarango_basic_maskings.a bin/libboost_system.a bin/libarango_shell.a bin/libclienttools_utils.a 3rdParty/jemalloc/lib/libjemalloc.a bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a -latomic -lresolv -lrt bin/libarango_static_strings.a bin/libarango_basic_features.a bin/libarango_basic_logger.a bin/libarango_basic_http_client.a bin/librocksdb.a 3rdParty/jemalloc/lib/libjemalloc.a /usr/lib/aarch64-linux-gnu/liburing.a bin/libarango_scheduler.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libfuerte.a bin/libnghttp2.a bin/libllhttp.a bin/libs2.a libssl.a libcrypto.a -ldl bin/libabsl_str_format_internal.a bin/liblinenoise-ng.a bin/libsnappy.a bin/liblz4.a bin/libarango_futures.a bin/libarango_assertions.a bin/libarango_crashhandler.a bin/libboost_system.a bin/libarango_basic_errors.a bin/libvelocypack.a bin/libabsl_cord.a bin/libabsl_cordz_info.a bin/libabsl_cord_internal.a bin/libabsl_cordz_functions.a bin/libabsl_cordz_handle.a bin/libabsl_crc_cord_state.a bin/libabsl_crc32c.a bin/libabsl_crc_internal.a bin/libabsl_crc_cpu_detect.a bin/libabsl_raw_hash_set.a bin/libabsl_hash.a bin/libabsl_city.a bin/libabsl_bad_variant_access.a bin/libabsl_low_level_hash.a bin/libabsl_hashtablez_sampler.a bin/libabsl_exponential_biased.a bin/libabsl_synchronization.a bin/libabsl_stacktrace.a bin/libabsl_graphcycles_internal.a bin/libabsl_kernel_timeout_internal.a bin/libabsl_symbolize.a bin/libabsl_malloc_internal.a bin/libabsl_debugging_internal.a bin/libabsl_demangle_internal.a bin/libabsl_time.a bin/libabsl_strings.a bin/libabsl_strings_internal.a bin/libabsl_throw_delegate.a bin/libabsl_base.a bin/libabsl_spinlock_wait.a -lrt bin/libabsl_int128.a bin/libabsl_civil_time.a bin/libabsl_time_zone.a bin/libabsl_bad_optional_access.a bin/libabsl_raw_logging_internal.a bin/libabsl_log_severity.a bin/libarango_build_id.a 3rdParty/libunwind/v1.7.2/src/.libs/libunwind.a -ltorque_base -lv8_base_without_compiler -lv8_compiler -lv8_init -lv8_initializers -lv8_turboshaft -lv8_libbase -lv8_libplatform -lv8_snapshot

echo arangoexport
clang++-19 -Wall -Wextra -Wno-unused-parameter -Wno-deprecated-declarations -Wno-error=unused-command-line-argument -mlittle-endian -march=armv8-a+crc+crypto -fno-stack-protector -Wsuggest-override -Wnon-virtual-dtor -Wno-missing-designated-field-initializers -g1 -gno-column-info -gz -O3 -fno-omit-frame-pointer -fstandalone-debug -Wl,--build-id=sha1 -fno-stack-protector -fuse-ld=lld -fopenmp=libgomp -llapack -lgfortran -static ../lib/BuildId/BuildId.ld -Wl,--build-id=sha1 client-tools/Export/CMakeFiles/arangoexport.dir/ArangoExportServer.cpp.o client-tools/Export/CMakeFiles/arangoexport.dir/ExportFeature.cpp.o client-tools/Export/CMakeFiles/arangoexport.dir/ExportFeatureOptions.cpp.o client-tools/Export/CMakeFiles/arangoexport.dir/ExportOptionsProvider.cpp.o client-tools/Export/CMakeFiles/arangoexport.dir/arangoexport.cpp.o -o bin/arangoexport -Lbin -L3rdParty/zlib/zlib-1.2.13 -L3rdParty/v8-build/v8/arm64.release/gypfiles -L3rdParty/v8-build/v8/arm64.release/obj.target/third_party/icu -L3rdParty/rocksdb bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a libssl.a libcrypto.a -ldl -latomic -lresolv -lrt 3rdParty/jemalloc/lib/libjemalloc.a -ldl bin/libboost_system.a bin/libarango_shell.a bin/libclienttools_utils.a 3rdParty/jemalloc/lib/libjemalloc.a bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a -latomic -lresolv -lrt bin/libarango_static_strings.a bin/libarango_basic_features.a bin/libarango_basic_logger.a bin/libarango_basic_http_client.a bin/librocksdb.a 3rdParty/jemalloc/lib/libjemalloc.a /usr/lib/aarch64-linux-gnu/liburing.a bin/libarango_scheduler.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libfuerte.a bin/libnghttp2.a bin/libllhttp.a bin/libs2.a libssl.a libcrypto.a -ldl bin/libabsl_str_format_internal.a bin/liblinenoise-ng.a bin/libsnappy.a bin/liblz4.a bin/libarango_futures.a bin/libarango_assertions.a bin/libarango_crashhandler.a bin/libboost_system.a bin/libarango_basic_errors.a bin/libabsl_cord.a bin/libabsl_cordz_info.a bin/libabsl_cord_internal.a bin/libabsl_cordz_functions.a bin/libabsl_cordz_handle.a bin/libabsl_crc_cord_state.a bin/libabsl_crc32c.a bin/libabsl_crc_internal.a bin/libabsl_crc_cpu_detect.a bin/libabsl_raw_hash_set.a bin/libabsl_hash.a bin/libabsl_city.a bin/libabsl_bad_variant_access.a bin/libabsl_low_level_hash.a bin/libabsl_hashtablez_sampler.a bin/libabsl_exponential_biased.a bin/libabsl_synchronization.a bin/libabsl_stacktrace.a bin/libabsl_graphcycles_internal.a bin/libabsl_kernel_timeout_internal.a bin/libabsl_symbolize.a bin/libabsl_malloc_internal.a bin/libabsl_debugging_internal.a bin/libabsl_demangle_internal.a bin/libabsl_time.a bin/libabsl_strings.a bin/libabsl_strings_internal.a bin/libabsl_throw_delegate.a bin/libabsl_base.a bin/libabsl_spinlock_wait.a -lrt bin/libabsl_int128.a bin/libabsl_civil_time.a bin/libabsl_time_zone.a bin/libabsl_bad_optional_access.a bin/libabsl_raw_logging_internal.a bin/libabsl_log_severity.a bin/libvelocypack.a bin/libarango_build_id.a 3rdParty/libunwind/v1.7.2/src/.libs/libunwind.a -ltorque_base -lv8_base_without_compiler -lv8_compiler -lv8_init -lv8_initializers -lv8_turboshaft -lv8_libbase -lv8_libplatform -lv8_snapshot

echo arangoimport
clang++-19 -Wall -Wextra -Wno-unused-parameter -Wno-deprecated-declarations -Wno-error=unused-command-line-argument -mlittle-endian -march=armv8-a+crc+crypto -fno-stack-protector -Wsuggest-override -Wnon-virtual-dtor -Wno-missing-designated-field-initializers -g1 -gno-column-info -gz -O3 -fno-omit-frame-pointer -fstandalone-debug -Wl,--build-id=sha1 -fno-stack-protector -fuse-ld=lld -fopenmp=libgomp -llapack -lgfortran -static ../lib/BuildId/BuildId.ld -Wl,--build-id=sha1 client-tools/Import/CMakeFiles/arangoimport_utils.dir/AutoTuneThread.cpp.o client-tools/Import/CMakeFiles/arangoimport_utils.dir/ImportHelper.cpp.o client-tools/Import/CMakeFiles/arangoimport_utils.dir/SenderThread.cpp.o client-tools/Import/CMakeFiles/arangoimport.dir/ArangoImportServer.cpp.o client-tools/Import/CMakeFiles/arangoimport.dir/ImportFeature.cpp.o client-tools/Import/CMakeFiles/arangoimport.dir/ImportFeatureOptions.cpp.o client-tools/Import/CMakeFiles/arangoimport.dir/ImportOptionsProvider.cpp.o client-tools/Import/CMakeFiles/arangoimport.dir/arangoimport.cpp.o -o bin/arangoimport -Lbin -L3rdParty/zlib/zlib-1.2.13 -L3rdParty/v8-build/v8/arm64.release/gypfiles -L3rdParty/v8-build/v8/arm64.release/obj.target/third_party/icu -L3rdParty/rocksdb bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a libssl.a libcrypto.a -ldl -latomic -lresolv -lrt 3rdParty/jemalloc/lib/libjemalloc.a -ldl bin/libboost_system.a bin/libarango_shell.a bin/libclienttools_utils.a 3rdParty/jemalloc/lib/libjemalloc.a bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a -latomic -lresolv -lrt bin/libarango_basic_logger.a bin/libarango_static_strings.a bin/libarango_basic_features.a bin/libarango_basic_http_client.a bin/librocksdb.a 3rdParty/jemalloc/lib/libjemalloc.a /usr/lib/aarch64-linux-gnu/liburing.a bin/libarango_scheduler.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libfuerte.a bin/libnghttp2.a bin/libllhttp.a bin/libs2.a libssl.a libcrypto.a -ldl bin/libabsl_str_format_internal.a bin/liblinenoise-ng.a bin/libsnappy.a bin/liblz4.a bin/libarango_futures.a bin/libarango_assertions.a bin/libarango_crashhandler.a bin/libboost_system.a bin/libarango_basic_errors.a bin/libabsl_cord.a bin/libabsl_cordz_info.a bin/libabsl_cord_internal.a bin/libabsl_cordz_functions.a bin/libabsl_cordz_handle.a bin/libabsl_crc_cord_state.a bin/libabsl_crc32c.a bin/libabsl_crc_internal.a bin/libabsl_crc_cpu_detect.a bin/libabsl_raw_hash_set.a bin/libabsl_hash.a bin/libabsl_city.a bin/libabsl_bad_variant_access.a bin/libabsl_low_level_hash.a bin/libabsl_hashtablez_sampler.a bin/libabsl_exponential_biased.a bin/libabsl_synchronization.a bin/libabsl_stacktrace.a bin/libabsl_graphcycles_internal.a bin/libabsl_kernel_timeout_internal.a bin/libabsl_symbolize.a bin/libabsl_malloc_internal.a bin/libabsl_debugging_internal.a bin/libabsl_demangle_internal.a bin/libabsl_time.a bin/libabsl_strings.a bin/libabsl_strings_internal.a bin/libabsl_throw_delegate.a bin/libabsl_base.a bin/libabsl_spinlock_wait.a -lrt bin/libabsl_int128.a bin/libabsl_civil_time.a bin/libabsl_time_zone.a bin/libabsl_bad_optional_access.a bin/libabsl_raw_logging_internal.a bin/libabsl_log_severity.a bin/libvelocypack.a bin/libarango_build_id.a 3rdParty/libunwind/v1.7.2/src/.libs/libunwind.a -ltorque_base -lv8_base_without_compiler -lv8_compiler -lv8_init -lv8_initializers -lv8_turboshaft -lv8_libbase -lv8_libplatform -lv8_snapshot

echo arangorestore
clang++-19 -Wall -Wextra -Wno-unused-parameter -Wno-deprecated-declarations -Wno-error=unused-command-line-argument -mlittle-endian -march=armv8-a+crc+crypto -fno-stack-protector -Wsuggest-override -Wnon-virtual-dtor -Wno-missing-designated-field-initializers -g1 -gno-column-info -gz -O3 -fno-omit-frame-pointer -fstandalone-debug -Wl,--build-id=sha1 -fno-stack-protector -fuse-ld=lld -fopenmp=libgomp -llapack -lgfortran -static ../lib/BuildId/BuildId.ld -Wl,--build-id=sha1 client-tools/Restore/CMakeFiles/arangorestore.dir/arangorestore.cpp.o -o bin/arangorestore -Lbin -L3rdParty/zlib/zlib-1.2.13 -L3rdParty/v8-build/v8/arm64.release/gypfiles -L3rdParty/v8-build/v8/arm64.release/obj.target/third_party/icu -L3rdParty/rocksdb bin/libarango_restore.a bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a libssl.a libcrypto.a -ldl -latomic -lresolv -lrt 3rdParty/jemalloc/lib/libjemalloc.a -ldl bin/libboost_system.a bin/libarango_shell.a bin/libclienttools_utils.a 3rdParty/jemalloc/lib/libjemalloc.a bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a -latomic -lresolv -lrt bin/libarango_static_strings.a bin/libarango_basic_features.a bin/libarango_basic_logger.a bin/libarango_basic_http_client.a bin/librocksdb.a 3rdParty/jemalloc/lib/libjemalloc.a /usr/lib/aarch64-linux-gnu/liburing.a bin/libarango_scheduler.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libfuerte.a bin/libnghttp2.a bin/libllhttp.a bin/libs2.a libssl.a libcrypto.a -ldl bin/libabsl_str_format_internal.a bin/liblinenoise-ng.a bin/libsnappy.a bin/liblz4.a bin/libarango_futures.a bin/libarango_assertions.a bin/libarango_crashhandler.a bin/libboost_system.a bin/libarango_basic_errors.a bin/libabsl_cord.a bin/libabsl_cordz_info.a bin/libabsl_cord_internal.a bin/libabsl_cordz_functions.a bin/libabsl_cordz_handle.a bin/libabsl_crc_cord_state.a bin/libabsl_crc32c.a bin/libabsl_crc_internal.a bin/libabsl_crc_cpu_detect.a bin/libabsl_raw_hash_set.a bin/libabsl_hash.a bin/libabsl_city.a bin/libabsl_bad_variant_access.a bin/libabsl_low_level_hash.a bin/libabsl_hashtablez_sampler.a bin/libabsl_exponential_biased.a bin/libabsl_synchronization.a bin/libabsl_stacktrace.a bin/libabsl_graphcycles_internal.a bin/libabsl_kernel_timeout_internal.a bin/libabsl_symbolize.a bin/libabsl_malloc_internal.a bin/libabsl_debugging_internal.a bin/libabsl_demangle_internal.a bin/libabsl_time.a bin/libabsl_strings.a bin/libabsl_strings_internal.a bin/libabsl_throw_delegate.a bin/libabsl_base.a bin/libabsl_spinlock_wait.a -lrt bin/libabsl_int128.a bin/libabsl_civil_time.a bin/libabsl_time_zone.a bin/libabsl_bad_optional_access.a bin/libabsl_raw_logging_internal.a bin/libabsl_log_severity.a bin/libvelocypack.a bin/libarango_build_id.a 3rdParty/libunwind/v1.7.2/src/.libs/libunwind.a -ltorque_base -lv8_base_without_compiler -lv8_compiler -lv8_init -lv8_initializers -lv8_turboshaft -lv8_libbase -lv8_libplatform -lv8_snapshot

echo arangosh
clang++-19 -Wall -Wextra -Wno-unused-parameter -Wno-deprecated-declarations -Wno-error=unused-command-line-argument -mlittle-endian -march=armv8-a+crc+crypto -fno-stack-protector -Wsuggest-override -Wnon-virtual-dtor -Wno-missing-designated-field-initializers -g1 -gno-column-info -gz -O3 -fno-omit-frame-pointer -fstandalone-debug -Wl,--build-id=sha1 -fno-stack-protector -fuse-ld=lld -fopenmp=libgomp -llapack -lgfortran -static ../lib/BuildId/BuildId.ld -Wl,--build-id=sha1 client-tools/Import/CMakeFiles/arangoimport_utils.dir/AutoTuneThread.cpp.o client-tools/Import/CMakeFiles/arangoimport_utils.dir/ImportHelper.cpp.o client-tools/Import/CMakeFiles/arangoimport_utils.dir/SenderThread.cpp.o client-tools/Shell/CMakeFiles/arangosh.dir/ArangoshServer.cpp.o client-tools/Shell/CMakeFiles/arangosh.dir/ShellFeature.cpp.o client-tools/Shell/CMakeFiles/arangosh.dir/ShellOptionsProvider.cpp.o client-tools/Shell/CMakeFiles/arangosh.dir/V8ClientConnection.cpp.o client-tools/Shell/CMakeFiles/arangosh.dir/V8ShellFeature.cpp.o client-tools/Shell/CMakeFiles/arangosh.dir/V8ShellOptionsProvider.cpp.o client-tools/Shell/CMakeFiles/arangosh.dir/ProcessMonitoringFeature.cpp.o client-tools/Shell/CMakeFiles/arangosh.dir/arangosh.cpp.o client-tools/Shell/CMakeFiles/arangosh.dir/v8-deadline.cpp.o -o bin/arangosh -Lbin -L3rdParty/zlib/zlib-1.2.13 -L3rdParty/v8-build/v8/arm64.release/gypfiles -L3rdParty/v8-build/v8/arm64.release/obj.target/third_party/icu -L3rdParty/rocksdb bin/libarango_v8.a bin/libarango_basic_http_client.a bin/libfuerte.a bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a libssl.a libcrypto.a -ldl -latomic -lresolv -lrt 3rdParty/jemalloc/lib/libjemalloc.a -ldl bin/libboost_system.a bin/libarango_shell.a bin/libclienttools_utils.a 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a -ltorque_base -lv8_base_without_compiler -lv8_compiler -lv8_init -lv8_initializers -lv8_turboshaft -lv8_libbase -lv8_libplatform -lv8_snapshot 3rdParty/jemalloc/lib/libjemalloc.a bin/libarango_async.a bin/libarango_async_registry.a bin/libarango_metrics_base.a bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a -latomic -lresolv -lrt bin/libarango_static_strings.a bin/libarango_basic_features.a bin/libarango_basic_http_client.a bin/librocksdb.a 3rdParty/jemalloc/lib/libjemalloc.a /usr/lib/aarch64-linux-gnu/liburing.a bin/libarango_basic_logger.a bin/libarango_scheduler.a -ltorque_base -lv8_base_without_compiler -lv8_compiler -lv8_init -lv8_initializers -lv8_turboshaft -lv8_libbase -lv8_libplatform -lv8_snapshot bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libfuerte.a bin/libnghttp2.a bin/libllhttp.a bin/libarango_futures.a bin/libarango_assertions.a bin/libarango_crashhandler.a bin/libboost_system.a bin/libarango_build_id.a 3rdParty/libunwind/v1.7.2/src/.libs/libunwind.a bin/libarango_basic_errors.a bin/libs2.a libssl.a libcrypto.a -ldl bin/libabsl_raw_hash_set.a bin/libabsl_hashtablez_sampler.a bin/libabsl_cord.a bin/libabsl_cordz_info.a bin/libabsl_cord_internal.a bin/libabsl_cordz_functions.a bin/libabsl_exponential_biased.a bin/libabsl_cordz_handle.a bin/libabsl_synchronization.a bin/libabsl_graphcycles_internal.a bin/libabsl_kernel_timeout_internal.a bin/libabsl_stacktrace.a bin/libabsl_symbolize.a bin/libabsl_malloc_internal.a bin/libabsl_debugging_internal.a bin/libabsl_demangle_internal.a bin/libabsl_time.a bin/libabsl_civil_time.a bin/libabsl_time_zone.a bin/libabsl_crc_cord_state.a bin/libabsl_crc32c.a bin/libabsl_crc_internal.a bin/libabsl_crc_cpu_detect.a bin/libabsl_hash.a bin/libabsl_bad_optional_access.a bin/libabsl_city.a bin/libabsl_bad_variant_access.a bin/libabsl_low_level_hash.a bin/libabsl_str_format_internal.a bin/libabsl_strings.a bin/libabsl_strings_internal.a bin/libabsl_base.a bin/libabsl_spinlock_wait.a -lrt bin/libabsl_int128.a bin/libabsl_throw_delegate.a bin/libabsl_raw_logging_internal.a bin/libabsl_log_severity.a bin/liblinenoise-ng.a bin/libsnappy.a bin/liblz4.a bin/libvelocypack.a

echo arangovpack
clang++-19 -Wall -Wextra -Wno-unused-parameter -Wno-deprecated-declarations -Wno-error=unused-command-line-argument -mlittle-endian -march=armv8-a+crc+crypto -fno-stack-protector -Wsuggest-override -Wnon-virtual-dtor -Wno-missing-designated-field-initializers -g1 -gno-column-info -gz -O3 -fno-omit-frame-pointer -fstandalone-debug -Wl,--build-id=sha1 -fno-stack-protector -fuse-ld=lld -fopenmp=libgomp -llapack -lgfortran -static ../lib/BuildId/BuildId.ld -Wl,--build-id=sha1 client-tools/VPack/CMakeFiles/arangovpack.dir/ArangoVPackServer.cpp.o client-tools/VPack/CMakeFiles/arangovpack.dir/VPackFeature.cpp.o client-tools/VPack/CMakeFiles/arangovpack.dir/VPackOptionsProvider.cpp.o client-tools/VPack/CMakeFiles/arangovpack.dir/arangovpack.cpp.o -o bin/arangovpack -Lbin -L3rdParty/zlib/zlib-1.2.13 -L3rdParty/v8-build/v8/arm64.release/gypfiles -L3rdParty/v8-build/v8/arm64.release/obj.target/third_party/icu -L3rdParty/rocksdb bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a libssl.a libcrypto.a -ldl -latomic -lresolv -lrt 3rdParty/jemalloc/lib/libjemalloc.a -ldl bin/libboost_system.a bin/libarango_shell.a bin/libclienttools_utils.a 3rdParty/jemalloc/lib/libjemalloc.a bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a -latomic -lresolv -lrt bin/libarango_static_strings.a bin/libarango_basic_features.a bin/libarango_basic_logger.a bin/libarango_basic_http_client.a bin/librocksdb.a 3rdParty/jemalloc/lib/libjemalloc.a /usr/lib/aarch64-linux-gnu/liburing.a bin/libarango_scheduler.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libfuerte.a bin/libnghttp2.a bin/libllhttp.a bin/libs2.a libssl.a libcrypto.a -ldl bin/libabsl_str_format_internal.a bin/liblinenoise-ng.a bin/libsnappy.a bin/liblz4.a bin/libarango_futures.a bin/libarango_assertions.a bin/libarango_crashhandler.a bin/libboost_system.a bin/libarango_basic_errors.a bin/libabsl_cord.a bin/libabsl_cordz_info.a bin/libabsl_cord_internal.a bin/libabsl_cordz_functions.a bin/libabsl_cordz_handle.a bin/libabsl_crc_cord_state.a bin/libabsl_crc32c.a bin/libabsl_crc_internal.a bin/libabsl_crc_cpu_detect.a bin/libabsl_raw_hash_set.a bin/libabsl_hash.a bin/libabsl_city.a bin/libabsl_bad_variant_access.a bin/libabsl_low_level_hash.a bin/libabsl_hashtablez_sampler.a bin/libabsl_exponential_biased.a bin/libabsl_synchronization.a bin/libabsl_stacktrace.a bin/libabsl_graphcycles_internal.a bin/libabsl_kernel_timeout_internal.a bin/libabsl_symbolize.a bin/libabsl_malloc_internal.a bin/libabsl_debugging_internal.a bin/libabsl_demangle_internal.a bin/libabsl_time.a bin/libabsl_strings.a bin/libabsl_strings_internal.a bin/libabsl_throw_delegate.a bin/libabsl_base.a bin/libabsl_spinlock_wait.a -lrt bin/libabsl_int128.a bin/libabsl_civil_time.a bin/libabsl_time_zone.a bin/libabsl_bad_optional_access.a bin/libabsl_raw_logging_internal.a bin/libabsl_log_severity.a bin/libvelocypack.a bin/libarango_build_id.a 3rdParty/libunwind/v1.7.2/src/.libs/libunwind.a -ltorque_base -lv8_base_without_compiler -lv8_compiler -lv8_init -lv8_initializers -lv8_turboshaft -lv8_libbase -lv8_libplatform -lv8_snapshot

echo arangobackup
clang++-19 -Wall -Wextra -Wno-unused-parameter -Wno-deprecated-declarations -Wno-error=unused-command-line-argument -mlittle-endian -march=armv8-a+crc+crypto -fno-stack-protector -Wsuggest-override -Wnon-virtual-dtor -Wno-missing-designated-field-initializers -g1 -gno-column-info -gz -O3 -fno-omit-frame-pointer -fstandalone-debug -Wl,--build-id=sha1 -fno-stack-protector -fuse-ld=lld -fopenmp=libgomp -llapack -lgfortran -static ../lib/BuildId/BuildId.ld -Wl,--build-id=sha1 client-tools/Backup/CMakeFiles/arangobackup.dir/ArangoBackupServer.cpp.o client-tools/Backup/CMakeFiles/arangobackup.dir/BackupFeature.cpp.o client-tools/Backup/CMakeFiles/arangobackup.dir/BackupOptionsProvider.cpp.o client-tools/Backup/CMakeFiles/arangobackup.dir/arangobackup.cpp.o -o bin/arangobackup -Lbin -L3rdParty/zlib/zlib-1.2.13 -L3rdParty/v8-build/v8/arm64.release/gypfiles -L3rdParty/v8-build/v8/arm64.release/obj.target/third_party/icu -L3rdParty/rocksdb bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a libssl.a libcrypto.a -ldl -latomic -lresolv -lrt 3rdParty/jemalloc/lib/libjemalloc.a -ldl bin/libboost_system.a bin/libarango_shell.a bin/libclienttools_utils.a bin/libfuerte.a 3rdParty/jemalloc/lib/libjemalloc.a bin/libzlibstatic.a -licui18n -licuucx -licustubdata 3rdParty/icu-legacy/lib/libicui18n64.a 3rdParty/icu-legacy/lib/libicuuc64.a -latomic -lresolv -lrt bin/libarango_static_strings.a bin/libarango_basic_features.a bin/libarango_basic_logger.a bin/libarango_basic_http_client.a bin/librocksdb.a 3rdParty/jemalloc/lib/libjemalloc.a /usr/lib/aarch64-linux-gnu/liburing.a bin/libarango_scheduler.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libarango_basic_utils.a bin/libarango_activities_global.a bin/libarango_activities.a bin/libarango_thread_owning_list.a bin/libfuerte.a bin/libnghttp2.a bin/libllhttp.a bin/libs2.a libssl.a libcrypto.a -ldl bin/libabsl_str_format_internal.a bin/liblinenoise-ng.a bin/libsnappy.a bin/liblz4.a bin/libarango_futures.a bin/libarango_assertions.a bin/libarango_crashhandler.a bin/libboost_system.a bin/libarango_basic_errors.a bin/libabsl_cord.a bin/libabsl_cordz_info.a bin/libabsl_cord_internal.a bin/libabsl_cordz_functions.a bin/libabsl_cordz_handle.a bin/libabsl_crc_cord_state.a bin/libabsl_crc32c.a bin/libabsl_crc_internal.a bin/libabsl_crc_cpu_detect.a bin/libabsl_raw_hash_set.a bin/libabsl_hash.a bin/libabsl_city.a bin/libabsl_bad_variant_access.a bin/libabsl_low_level_hash.a bin/libabsl_hashtablez_sampler.a bin/libabsl_exponential_biased.a bin/libabsl_synchronization.a bin/libabsl_stacktrace.a bin/libabsl_graphcycles_internal.a bin/libabsl_kernel_timeout_internal.a bin/libabsl_symbolize.a bin/libabsl_malloc_internal.a bin/libabsl_debugging_internal.a bin/libabsl_demangle_internal.a bin/libabsl_time.a bin/libabsl_strings.a bin/libabsl_strings_internal.a bin/libabsl_throw_delegate.a bin/libabsl_base.a bin/libabsl_spinlock_wait.a -lrt bin/libabsl_int128.a bin/libabsl_civil_time.a bin/libabsl_time_zone.a bin/libabsl_bad_optional_access.a bin/libabsl_raw_logging_internal.a bin/libabsl_log_severity.a bin/libvelocypack.a bin/libarango_build_id.a 3rdParty/libunwind/v1.7.2/src/.libs/libunwind.a -ltorque_base -lv8_base_without_compiler -lv8_compiler -lv8_init -lv8_initializers -lv8_turboshaft -lv8_libbase -lv8_libplatform -lv8_snapshot
